Welcome to our World! Where we serve you cookies to ensure you get the best viewing experience on our site.

Did you know that you can remove censorship board-wide, use our advanced search functions, be notified when new content is posted, join our memberships, set episodes to show in any order you want & more if you are logged into your account?

Register or sign in here: ucp.php?mode=register

Saturday Night (2024)

Historical & Biography Movie Collection.
(Alternate History/Period Piece/Biopic/Bhakti/etc.)

Moderators: Maskath3, sidolanters, GabrielAlejo2341

Biographies Movie Collection

Saturday Night (2024)

Post by bunniefuu »

(indistinct chatter)

LORNE:

All right, Chevy.

ROSIE:

Chevy, you're very handsome.

-CHEVY: Oh, stop it.

-How did you become so funny?

Uh, what was the first part?

(laughter)

GILDA: Lorne said if I just

stared into the camera

that that'd take a lot of guts.

-ROSIE: Danny.

-(laughter)

There were bells on the hill,

but I never heard them ringing.

LORNE:

Action, Laraine.

LARAINE:

Um...

-Hi.

-(laughter)

CREWMAN:

Did I spell your name right?

I'm Garrett Morris, talking

to all you white Americans

about the way Black people

have been treated in America.

Now, I know a lot of you

feel guilty, and you should.

(laughter)

You see, um, having a catheter,

a lot of people think

it's funny,

and they like to see me dance.

(laughter)

Now, I-I look up,

and I-I see...

I see it coming down, now,

real quick,

and I see discs,

whirling discs.

-(laughter)

-DAN: All right.

Oh, really? Ra-Rad... Radney?

I'm not gonna talk about...

Nah.

DAN: Whirling around,

whirling around.

I see all kinds of lights.

Then they just drop me.

In order to get that much iron,

you'd probably have to overeat.

Send your check or money order

to White Guilt Relief Fund.

Are we ready? Should we go?

-(horns blasting)

-(whistle blares)

RADIO ANNOUNCER:

At the sound of the tone,

the time will be 10:00 p.m.

NBC PAGE:

Free show.

RADIO ANNOUNCER: There's

wedding bells again for...

Plenty of tickets left, guys.

Free show.

No?

-Hey, free show, man.

-f*ck off.

Hey, sir, free comedy show.

Plenty of seats.

Perfect for date night.

Um, you are invited

to a new variety spectacular

featuring a parade

of comedy and musical acts

ripped from the charts.

-Jesus Christ.

-Where did they unearth

such a cavalcade of talent?

Hey, man. You okay?

(sighs) Maybe ask me again

in 90 minutes.

Why? What happens

in 90 minutes?

Uh, we go live.

Oh. (chuckles) Far out, man.

Congrats. Miss? Show?

-Thank you.

-Hey, wait, if it's live,

then why the hell

are you down here?

-Free show?

-LORNE: I'm...

f*ck's sake.

-...waiting for...

-ANDY: Mr. Michaels.

Ah. It's 10:00, Andy.

-Here, come on.

-(drivers shouting angrily)

MRS. KAUFMAN:

Wh-Where do I park?

You are invited to

a new variety spectacular...

Uh, you can just pick him up

at 1:00, Mrs. Kaufman.

-Do you like my suit?

-Very elegant, Andy.

-This is my favorite suit.

-We're heading out. Come on.

Where did they unearth

such a cavalcade of talent?

LORNE:

Come on, Andy.

-Bye, Mommy.

-Bye, honey. I love you.

-LORNE: Andy, come on.

-DRIVER: Move, you as*h*le!



Andy, please, come on.

ANDY:

This is beautiful.

LORNE:

Yeah.

You know, actually, down there

is where Diego Rivera was hired

to paint a fresco

for the American worker?

ANDY:

I cannot see this.

Well, no one can

'cause Diego was a commie

and added Vladimir Lenin

in the middle of the night,

so the Rockefellers

had it plastered over.

Deliveries use the back.

-I'm producer of the show.

I'm... -Where's your badge?

-My... (sighs)

-Where's his badge?

I... Look, my name

is Lorne Michaels.

I'm the producer

of "Saturday Night."

-The whole night? -Hey, hey,

he's good. He's good.

Yeah, the whole night. I'm

producing every show in there.

-Let him in. Let him in.

-I'm good. You see?

Live on a Saturday night?

Must be some show.

Hey, you're doing a great job.

Really, great stuff.

What kind of name

is "Saturday Night"?

LORNE:

Andy, come on, please.

ANDY:

Okay. We're rushing.

Uh, eighth floor, and book it.

Put on your seat belts.

(sighs)

So, big night.

LORNE:

Oh, Andy, have you had dinner?

Uh, yes, I-I had spaghetti.

Oh, that sounds delicious.

Uh, hey, Lorne, I'm getting

calls from upstairs.

-You ordered a llama?

-A llama?

Yeah, we all decided it was

much funnier than a donkey.

Right. Just, the guys

down at the loading dock

weren't expecting a...

you know, livestock.

Well, NBC did ask for something

fresh and unexpected.

Th-That is true. That's true.

Uh, just, you know, they also

weren't expecting you to demand

an overhaul on the entire

lighting and sound package.

Did anyone ask Edison

what a light bulb was

before he harnessed

electricity?

Who are you in the metaphor?

The light bulb?

We can't expect people

to recognize

something they've never

seen before.

Right, okay, yes,

you're correct.

But just, how about

a final script?

It's not that kind of show.

Okay, well, what kind

of show is it, Lorne?

Do you even know

what the show is?

Of course.

Are you gonna share it

with the rest of us?

Yes.

(elevator bell dings,

doors open)

In 88 minutes.

Oh, my God.

Uh, have you tested the quality

of the sound system?

-Uh, no, I haven't.

-'Cause the speakers

look left over

from Arturo Toscanini.

Uh, I mean,

that's not really my job.

CREWMAN:

Coming through!

d*ck: Lorne,

did you order more lights?

-Hey, come on! Move it!

-Is this your card?

How'd he do that?

He's a f*cking magician,

numb nuts.

-LORNE: Hey, Neil.

-Oh, hey.

You got to be right by my side,

man, locked to my hip.

Remember, when you're here,

you're not my cousin.

-You're my executive assistant.

You're important. -Really?

-Like, in the credits, it'll

say? -Well, no, but you and I

-will know. -They're looking

for you in the control room.

-Okay. -Also, Belushi hasn't

signed his contract yet.

-Right. -Oh, oh,

and the llama has arrived.

Oh, great. Thanks, Barbara.

Neil, memo:

We need to reeducate

the NBC pages on the show.

You should've heard

the guy outside.

d*ck:

What the hell is this?

"Saturday Night," it's

a new kind of entertainment.

It's abstract and defiant.

Avant-garde yet blue-collar.

d*ck:

And it's also a comedy.

GILDA:

Oh.

Oh. Oh.

Gilda, come on.

We need you for rehearsal.

Oh.

Oh, careful.

They're still drying.

-This is monumental work, Edie.

-...is Mr. Martin Gresner.

Mr. Gresner, would you please

tell our studio audience...

Jane, Jane,

you're still attached.

...just how you became

a victim of a shark bite?

You are so fluffy.

Hey, come on, Andy.

-You cut my n*zi Dr. Dolittle?

-Uh...

(German accent) He has ways

of making the animals talk.

I'll check with

the run-of-show board.

-Can you check again?

-Package was addressed

to Al Franken and Tom Davis.

I don't know

what to tell you fellas.

How do you lose

28 gallons of blood?

85 minutes till showtime!

-(bell ringing)

-Come on, guys.

These transitions

need to be crisp.

Pretend like there's a hooker

holding a sandwich,

waiting for you stage right.

We still need to rehearse

five sketches.

Are we any closer

on lighting cues?

GARRETT: Hey, Schiller,

what are you up to?

I'm burning sage,

removing demons.

Ooh, Garrett don't do voodoo.

Uh, Andy, this is Billy Crystal

and Valri Bromfield.

-They're both in the show.

-Andy!

LORNE: They're both very nice.

Please stay with them, okay?

Now, Andy is

a certifiable comedic genius.

-He's redefining the form.

-Nice to meet you, Andy.

BILLY: We are in

the presence of greatness.

Where is the bathroom?

LORNE: Neil, can you show Andy

to the washroom?

-Yeah, yeah.

-There you are. Lorne!

-Uh, yeah? -I can't authorize

the purchase of an antique...

d*ck, Jim has a question

about something.

-Here, let's talk over here.

-He's out of control.

-Uh, okay. Hey, I understand.

-Th-This isn't a budget.

It's a ransom note.

Someone asked for

last Friday's "Johnny Carson"?

Where the f*ck you been,

Charlie?

Sorry, I've been busy. I'll be

back in a little bit, okay?

Okey-dokes. So, as it stands,

we have four host monologues,

two stand-ups,

two musical guests--

each with two performances--

a solo piece by Andy Kaufman,

five parody commercials,

"Weekend Update,"

a film by Albert Brooks,

Jim Henson's Muppet thing,

not to mention seven sketches.

-Something for everybody.

-Yeah, it's a lot of show.

-It won't fit.

-We don't know that.

I know that.

The dress rehearsal

was three hours.

Audrey thinks we're tight.

Audrey thinks

it's time to make some

-tough decisions, actually.

-Lorne, just cut some things.

-No, we will, but...

-CHEVY: Am I still in the show?

Jesus Christ.

Sorry. Tripped over my p*nis.

-Still in the show, Chev.

-Oh, I know.

Hey, you remember Jackie,

my girlfriend?

-Fiance.

-It looks expensive.

She is. It is.

I never know

when you're kidding.

Hey, Chev, can I, uh...

Can you show a little goodwill

to your costar?

-Who? Belushi?

-Mm-hmm.

God, God, what the f*ck's

the matter now?

I think it's just

the new dynamic,

and there are

a lot of expectations...

No, I'll tell you

what the issue is.

We're not doing

"The Radio Hour" anymore,

and he's built like

an Albanian cheeseburger.

Chevy can't help if people

are responding to his face.

I mean, I could, but I won't.

Right, well,

no one's asking you

to deny your own magnetism,

Chevy.

Maybe there's other roles

for John to play,

like a hobo or a troll.

Or a fire hydrant.

-Or a Volkswagen.

-Ah.

Or a hemorrhoid.

-You're looking sharp, Patches.

-(chuckles) What?

AUDREY:

You have to cut something.

Yeah. Yeah.

-Uh, Neil?

-NEIL: Oh, yeah.

Get me a key to this door.

In fact, I want keys

to all the doors.

In the building?

If you can.

DAVE WILSON: Frame up

on the shot, okay, Cameron?

-Let's go.

-(commercial playing)

Bring camera two.

That looks okay.

Hey, guys.

-Hey, Lorne.

-Down in front.

-Down in front. Down in front.

-Down, down. Thank you, sir.

-Dave, how are we looking?

-Oh, g-good, good, good.

Still working on the 47 notes

you gave me in your last visit.

Okay. H-How is morale

looking out there?

-Morale?

-Mm-hmm.

Uh, I think I can, uh,

speak for the entire crew

-when I say this is exactly

-(tapping desk)

where we want to be

on Saturday night.

-Okay. Great.

-Yeah. Yeah.

WILSON:

Rocky? Wake up, will you?

STEW:

Give me lights 25B, 25C.

Half down on 31. That's 32.

You've done this before, right?

CREWMAN:

Man, that's a lot of lights.

Charlie,

you're gonna drop a testicle

-lifting that thing.

-Good job, Charlie.

JOE:

All right, quiet, please!

Here we go. Rehearsal's up.

Actors on their marks.

All right. Hey, guys,

we only have

two minutes of commercials

to make it from stage right

to stage left.

STEW: Anybody know

the load bearing on the booms?

Oh, hello, fellas.

-What's up, Joe?

-Hey, Joe. -Joe.

Can I get you anything?

-Refreshment? Mai tai?

-I'll take a Schaefer.

Try and at least act like

you're f*cking working, please.

John, thank you

for your patience.

Moments away, okay?

BARBARA:

All right, next card:

"Al 'Bud' Franken."

Next card: "Tom 'Bud' Davis."

Okay, so this is... this is...

this is a bit or...

Look, I don't get half the sh*t

that they do.

Next card: "Rosie 'Bud,'" uh...

Lorne, is Rosie going with

"Michaels" or "Shuster"?

That's a good question.

-Should I ask Rosie?

-No, no, no, I'll-I'll...

-I'll take care of it.

-All right.

WILSON: That's good.

That's actually looking good.

MICHAEL:

She's been at it for hours.

She's simply doing her job.

We have to comply

with NBC standards.

Well, I refuse to comply.

-Uh, Mr. O'Donoghue.

-MICHAEL: Mm-hmm?

On page 12...

oh, what is "clam diving"?

I believe the act

of harvesting mollusks.

JOE:

Stew. You're k*lling me here.

I just need the light

for "Home Invasion."

Talk to the wunderkind.

He's trying to light f*cking

-"Jesus Christ Superstar."

-Those are excuses.

There's four people up there.

Get 'em lit.

I'm glad you're having fun,

but this isn't helpful.

If that piglet

disfigures my work,

I'm gonna turn her uterus

into a sock puppet.

(Lorne scoffs)

What is "zipper dinner"?

-(laughter)

-Two, ready for the entrance.

How many of these

did you hide in the script?

Maybe a dozen.

It's like a scavenger hunt.

I know what blue ba*ls are.

You don't say.

JOE:

Come on, people.

Move with purpose.

Let's do this.

-Al, is that-that your one?

-CRANE OP: It doesn't look...

JOE:

Come on, give it.

All right, quiet, please.

Rehearsal is up.

as*ault and burglary.

JOE: Okay, actors

on their marks, please.

Cameras on their marks.

Here we go.

Okay, let's see if we can get

through one of these skits.

Sketches. Davey, please.

-WILSON: Okay. Ready,

camera one? -JOE: And...

-action on rehearsal.

-WILSON: Take camera one.

Oh, look, honey.

"Boeing, Boeing"

with Jerry Lewis

is on in ten minutes.

Ready, camera two?

Take camera two.

Ah, sweetheart, I'm tired.

I think I'm just gonna have

another glass

of diet root beer

and go to bed, okay?

-Aykroyd!

-Cue Danny.

(banging at door)

What's the problem?

JOE:

What's going on, Dan?

DAN:

It's a little lodged.

Hi there.

Please do not be alarmed.

This is only a simulated

as*ault and burglary.

Repeat, this is a simulated

as*ault and burglary.

This could happen to you

at any time.

-In fact, it just has.

-Call the police!

No, no! Don't call the police.

I am the police.

Well, I might be anyway.

(laughter)

Hi. Mr. and Mrs. Kromer?

JOE:

Hold. Aykroyd, one giant step

-to the right, please.

-Uh, yeah. My right?

-Yes.

-DAN: Sure.

Uh, say, man, you want me

to say anything in this,

or am I the silent robber type?

Uh, I think we're gonna stick

to the script this time.

-What script?

-Thanks, Garrett. Okay.

Here we go.

And action on rehearsal.

Hi. Mr. and Mrs. Kromer,

my name is Kenny Vorstrather.

I'm president of

Trojan Horse Home Security.

I've broken into your home

tonight to illustrate to you

-and your family just how...

-(clattering)

(frantic yelling, gasping)

DAN:

Have your girders been checked?

(crewmen and John clamoring)

JOHN: I'll f*cking break

your f*cking jaw!

-LORNE: Whoa, whoa, whoa, whoa.

-JOE: Play the cameras back.

Play the cameras back.

Let's go.

-John, are you hurt?

Are you hurt? -Get the...

-Oh, my God.

-Jesus Christ!

I need a new g*n.

This is, uh... It's, uh...

Where's props for me, please?

Somebody clear the children,

please!

-Hey, Stew, lights out, please.

-Somebody get the fire?

JOHN: Come on.

You got any more f*cking lights

-you want to drop on us?

-Yeah, maybe.

Maybe, you m*therf*cker!

You want me to break

your f*cking jaw for you?

f*cking amateur hour!

I'll break your f*cking jaw

for you, m*therf*cker!

-JOHN: Get the f*ck off me!

-Hey, hey, hey!

How dare you

endanger my actors?

-Lorne, Lorne. -Oh, really?

Yeah, oh, you're...

you're the one asking

for a hundred

-f*cking light cues, pal!

-Feel free to let me know

when my expectations

surpass your abilities.

You know, I-I don't know, guys.

It was kind of exciting.

Like, it's probably good luck.

Wallie.

Uh, this one's not gonna work.

I need, uh, something

with a little more heft.

It's got no stopping power.

You know what I mean?

Script said "p*stol."

Well, the script

specifically called for

a Smith & Wesson K-Frame

Model 19 Combat Magnum.

-Can we go again?

-Uh, in this death trap?

Well, we've worked out

the kinks. Give me that.

GILDA: You know, I still think

it was kind of funny.

How high will

this thing go, Al?

-Gilda. Gilda. -CRANE OP:

Say hello to the camera, boys.

-(Gilda laughing)

-There's, um, home base.

Kid, this ain't an armory.

No one's gonna notice

the difference.

I'll tell you who'll notice:

a few of the fine folks at home

who lugged M16s

through four feet

of swamp juice in Quang Nam.

-Hey, boys.

-(crewmen whooping, whistling)

Guess I picked the wrong day

to not wear underwear.

Don't look too hard.

Proud of yourself?

I give you and your circus

-till the end of the week.

-Oh, that's funny,

'cause I give you

till the end of the day.

-All right, everyone...

-Ah, ah, ah, ah, ah. Hey, hey.

Hey, hey, hey, hey, hey, hey.

(indistinct,

overlapping chatter)

Mm-hmm!

Thank you, hermano.

d*ck: Yeah, I-- Neil,

not with the keys right now.

STEW: I been in this

for almost 20 f*cking years,

and sh*t like this

has never happened...

GARRETT:

Pow, pow! Pow, pow!

(Garrett chuckling)

Hey, come on, man.

Violence, really?

(laughs) My main man, Jim.

Say, uh, sorry for sh**ting

your Muppets, man.

They're not just...

They're your costars.

Say, you...

you all right there, Jim?

Yes.

No.

I don't think the writers

on the 17th floor speak Muppet.

They tied a belt

around Big Bird's neck

and hung him

from my dressing room door.

Hey, I heard about Big Bird.

So sorry.

Autoerotic asphyxiation.

Who knew?

(scoffs)

You're full of baloney.

Uh-oh. Cursing.

STEW: Consider me the first rat

off this sinking ship!

-Oh, really? Oh...

-Please don't jump to...

LORNE:

Oh, wow, that's mature.

Well, what can I say?

Bon voyage.

Lorne, he was

our lighting director.

-We need lights.

-I'm sure there's someone else

in the building

who can push a button, d*ck.

Hey, he's the only one

who knows the location

of the 200 lights

you asked for.

What is this?

What's the meaning of this?

Who did this?

(laughter)

Hey, I thought

we were making a comedy.

(laughter)

(band playing soulful tune)

(camera clicks)

BILLY PRESTON:

Hey, oh

-GARRETT: Mm!

-Yeah.

Sounding good, guys.

-(chuckles) Yeah. Okay.

-(band stops playing)

(chuckles) All right.

Say, uh, we actually

worked together before.

I sang backup for Belafonte.

(laughs)

Catch that?

(band laughing)

Drink the coconut water

Four to five

Man, it's good

for your daughter

Four to five

Coco got a lotta iron.

(laughter)

Guy singing, too.

Man, how many people

-do they have playing tonight?

-Wow.

No, no, no, see, I am one of

the comedic performers, man.

-PRESTON: Uh-huh.

-Yeah, I'm in the...

-I'm in the cast.

-You-you...

you are

a professional comedian?

Uh, uh, well, uh, no,

not-not-not-not by trade.

-Uh...

-Okay, uh...

You see, I'm actually

a playwright.

-All right.

-Perhaps you saw my work

at the Black Arts

Repertory Theatre in Harlem.

Yeah, I must have missed that.

(instruments warming up)

Yeah, I actually don't know

why they hired me, man.

(laughs)

Yeah, you seem a little tight.

-Little...

-Do I?

Yeah, you got to kind of

loosen it up for the show.

Say, Alvin.

Hook Mister, Mister...

-What's your name?

-Uh, Garrett Morris.

Garrett Morris, y'all,

the comedian.

Yeah, hook

Mr. Garrett Morris up

with a little bit

of confidence.

You know what I'm saying?

Yeah, come...

-Oh, okay.

-Go ahead and get it.

Medical-grade.

sh*t so light, air at

the bottom of the bottle.

You gonna float.

Float?

-I'm gonna put this away.

-Yeah, yeah, yeah.

This is, uh, ill*gal.

-(laughing)

-(band resumes playing)

PRESTON: Yeah, well, you gonna

need it for your comedy.

-Right.

-Yeah.

(both laughing)

-Yeah, yeah. Yeah.

-All right.

All right, y'all, let's get it.

JOE:

Scotty, sound check.

All right, everyone,

quiet for sound check.

Sound check!

-(band playing "Right On")

-(sighs) This should be fun.

(music playing quietly

over headphones)

Is this... is this full volume?

It's the whole enchilada.

Uh, it sounds

pretty adequate to me.

Well, this isn't Wimbledon.

It needs to feel like a rock

concert for everyone at home.

Uh, Lorne has such

a deep appreciation for music.

-Shouldn't we have more mics?

-One band, one mic.

d*ck, this needs to be fixed

for-for tonight.

It's what I've been

talking about.

Three, four!



Whoa, whoa, whoa.

Is this for John?

Yeah. I heard he's in makeup.

Do you like being yelled at

or something?

Here, I've got this.

Where are you going?

(babbles)

Pretty mama

You're looking fine

You do your thing

And I'll do mine

Right on...

Oh, Jim, do not bet

on that hand, please.

Got my own thing

And I'm going right on

Yeah!

Can you hold the door?

(indistinct chatter)

Ooh. Easy on the macaroni,

Carmine.

CARMINE:

All right.

ROSIE: You don't want

to hurt your stomach.

CARMINE:

All right, Rosie.

(song continues in distance)

ROSIE:

There he is.

The star of the show.

Oh, come on, Rosie,

not the f*cking bees.

I'm not a dashboard ornament.

No. You're adorable

is what you are.

And all that fur-- every girl's

gonna want to squeeze you.

I am a trained professional.

Well, you better watch

where you point that stinger.

Come on.

You want a little cig?

LARAINE: What happened

to my reporter costume?

Blaine Hotel?

It's a five-second changeover

from the reporter

to ancient Greece, okay?

Lorne didn't think

you'd have time

to get into your toga.

O-Okay.



-DAN: Excuse me. Ma'am.

-(pats bottom)

-(laughs)

-Oh, don't be alarmed.

You're dealing with a

fully qualified male strumpet.

Hey, Rosie, I got the

latest version of "New Dad."

Okay.

-Behave. Bee-have.

-(John grunting)

ROSIE:

Mm-hmm. (chuckles)

DAN: I can assure you

professional hygiene...

LARAINE:

Oh.

...discretion,

animal gratification.

Listen, strumpet.

It's Fred Garvin,

male prost*tute.

How much is this gonna cost me?

-(pats bottom)

-Hey.

Speaking of costumes,

I told them to make

-those hot pants extra hot.

-DAN: Yummy.

Oh, Lorne, we're gonna go

check out the cut on "New Dad."

You want to see?

(song ends)

Holy sh*t. Holy sh*t.

Sorry, Lorne.

Jesus.

Hey, I heard John doesn't like

the bee costume.

-You know anything about this?

-It's not a costume problem.

He thinks he's Brando.

-He's better than Brando.

-Lorne. Lorne.

I'm-I'm working on it, d*ck.

He's better than Brando.

He's more important even.

-He'll be studied.

-They will study his liver.

-Move away! Let's go! -John is

better when he's angry.

Rosie, you understand

that in an hour

I owe a television program?

I made a covenant with

the National Broadcasting...

-A covenant, huh?

-Yeah, a covenant,

and I'm on the hook for

90 minutes of live television.

Okay, Abraham.

(sighs)

Rose, must you

turn him into a bee?

I am not turning him

into a bee.

Thanks, Tom.

He is a man in a bee costume.

-There is a difference.

-Mm.

It's an image

you can't get out of your head.

It's postmodern. It's Warhol.

It's iconic.

Mm-hmm. Where do these ideas

even come from?

Oh, I just send

an imaginary dog

-to fetch an imaginary stick.

-Oh, yeah?

-Must be some dog.

-He's very well trained.

Honey, I'm home.

Hey, pal. Hey.

(laughs) How are ya?

LORNE:

Looks like Chevy's fiance

slipped and fell

into another segment.

Jacqueline's gonna be hosting

the show if you're not careful.

Jesus Christ.

NARRATOR (over monitor):

...a wonderful family.

Everything you need

for the future.

-Danny's good in this.

-Yeah, he is.

NARRATOR: What if you were

suddenly out of the picture?

LORNE: Can we add sound there

over the "X"?

EDITOR:

Like a buzzer?

-No, funny, like-like a bell.

-Oh, good call.

ROSIE: And if we could

hold on the photo

for another eight frames.

LORNE:

Um, 16 frames.

NARRATOR: Everything...

(audio distorts)

Were you, uh...

thinking of going home

with him tonight?

Uh, with Danny tonight?

Yeah, I mean,

I'm not suggesting...

Uh, if you need alone time,

I can just...

No, no, no,

I just didn't know if...

It's opening night,

so I figured

-that it wasn't the right time.

-Neither did I.

Well, then why are you asking?

Uh, just avoiding surprises.

-But you love surprises.

-Oh, I love surprises.

Like Anne Frank loved

her drum set.

-(editor chuckles)

-LORNE: Don't encourage her.

ROSIE:

Can you hold on that photo

for another eight frames,

please?

-It's always eight frames.

-Eight frames is a beat, so...

Can you believe that I need

to cut an hour of the show?

Oh, NBC doesn't want a

three-hour sketch comedy revue?

Oh, Jesus, Rose,

don't call it that, please.

Well, what is it, then?

Honey, I'm home.

NARRATOR:

Yes, it's New Dad...

LORNE:

I spent years collecting

orphaned comedians

off the street.

I know.

They sleep on our dinette,

and they whiz in our sink.

By some miraculous accident,

I found a place to call home

for our little circus

of rejects

on national television.

Rose, this is our shot.

It's a shot.

Rose.

You're actually nervous.

Oh, uh,

Barbara was asking about, um,

your credit on the show.

I figured you'd go

with "Michaels."

Is that what you want?

I... (sighs)

I mean, you know,

we're married.

You're my wife.

I figured it's

the straightest line.

Lorne, we're married,

but I'm not your wife.

Yeah, I don't think

that'll fit on the crawl.

Well, what would you prefer?

Lorne, Lorne!

NBC execs are waiting

in the green room for you.

-Oh, f*ck.

-Uh, VTR needed this yesterday.

LORNE:

Well, it looks great.

Tom, Al, what's this about?

-Hey, Lorne.

-Hey, Lorne.

-A last-minute piece.

-Just in case you need it.

I don't. What's the gag?

Uh, we're gonna dress

Aykroyd up as Julia Child.

-America's favorite chef.

-Okay.

And right as she's carving up

a turkey on live television...

She slices open an artery.

-Blood everywhere.

-Everywhere.

Oh, that's the whole pitch?

Yeah, just America's favorite

chef painting the walls

-with her insides.

-Total gore fest.

DAN: It's gonna be

utter carnage, boss.

(imitating Julia Child)

Oh, no. I'm Julia Child,

and I've cut the dickens

out of my finger.

-Sounds promising.

-Wait, wait, boss,

I didn't even get

to the good part yet.

-Just put down a tarp.

-Yeah.

He doesn't like

the Julia Child bit.

Uh, George?

-How's Carlin?

-Warming up the pipes.

Okay. Well, uh, I heard Belushi

hasn't signed his contract yet.

(scoffs) Formality.

Uh, yeah, well,

they're pretty formal here.

Uh, speaking of,

the folks in Standards

are a little uneasy

about the parody commercial

playing right before

the regular ads.

I think they think the viewers

might be a little confused.

One might argue that's what

makes it humorous, d*ck.

Yeah, but, Lorne, at what point

are we not just making fun

of the audience?

Oh, hardly.

It's commedia dell'arte.

If anything, it'll make

the other commercials

feel all the more real,

and the sponsors

will probably thank you.

-Oh.

-Who's in there?

-Should I be concerned?

-No, uh, just try not to use

words like "underground"

or "revolutionary."

-I'm not exactly Che Guevara.

-Yeah.

(indistinct chatter)

What the f... There's like

a thousand people in there.

Fifty. The affiliates

from across the country.

Lorne, they're excited

to see the show.

I don't have time

for this, d*ck.

Lorne, these are the people

that will decide

whether or not we have a hit.

They choose whether

we go on the air.

We need them.

(sighs)

-Three minutes.

-Tops.

-Uh, gentlemen.

-Gentlemen.

-Hello. Lorne Michaels.

-(lively chatter)

Hi. Lorne Michaels.

Hi. Lorne Michaels.

Nice to meet you. Pleasure.

Lorne Michaels. I'm...

This is my show. Hi.

Where are we flying in from,

gentlemen?

-d*ck: Such a pleasure.

-MAN: Chicago.

-MAN 2: New Orleans.

-LORNE: New Orleans. Wow.

Fantastic. Well, uh,

we're very lucky to have

you Southerners here.

Hi. Nice to meet you.

Hi, gentlemen. Lorne Michaels.

I'm the creator of the show.

Hi. Wow, firm handshake. Hi.

Appreciate your support,

gentlemen. Thank you.

-Hello. Hi.

-Tallahassee.

Tallahassee? Wow.

-Ladies and gentlemen...

-Hi.

(sighs) Who am I kidding?

Gentlemen.

(scattered chuckling)

Can I see that?

Thank you.

Hope this isn't the only thing

getting sucked on

this weekend, boys.

-(laughter)

-Jesus, you guys look like

the cast of "Godfather"

if it was shot in Alabama.

(laughter)

I see some cowboys here.

That's a hell of

a ten-gallon hat.

You look like you're ready

for a date with livestock.

(laughter)

Welcome to New York.

It's quite diverse.

If you want to meet

Black people, go to Harlem.

If you want to meet Jews,

come to our writers' room.

(laughter)

Sir, you look like

you're from Ohio.

My, uh... my favorite thing

about Ohio...

Let me introduce you

to our head writer,

-(laughter)

-our prince of darkness,

Michael O'Donoghue.

MICHAEL:

Mm, thank you.

(clears throat)

Thank you, Chevy.

Um, I'm certain

you all know Mister Rogers,

perhaps the most kind

and gentle man

in all of television.

This is my impression

of Mister Rogers

plunging 18-inch steel

sewing needles into his eyes.

(clears throat)

(screaming)

(laughter)

(screaming continues)

Okay, okay. Thank you, Michael.

Um, well, now you know why

they put us on at midnight.

Um...

Uh, hello, everybody.

My name is Lorne Michaels.

I'm the producer and creator

of "Saturday Night."

We have a wonderful show

for you this evening.

George Carlin,

the great Billy Preston.

A film by Albert Brooks.

Jim Henson's Muppets.

(laughing)

(sighs)

We're, uh, excited for tonight.

Uh, because there's never been

a television show

made for or by the generation

that grew up

watching television, so...

In the words of my dear friend,

Che Guevara,

-this is the revolution.

-Viva la revolucin!

-Yes. Yes.

-(cheering)

-Yes.

-Okay. Thank you, Chevy.

Who's with us?

Heads on pikes!

Blood will run in the streets!

-Come on!

-(cheering)

Gentlemen, behold.

If you listen closely,

you can hear Buffalo Bob

shuckin' the cob

with Howdy Doody.

Lorne can get

a little passionate,

and so can Chevy here.

-"Blood in the streets."

-(chuckles) Yeah.

-Well, that sounds delightful.

-Mm-hmm.

How much are we spending

on this insurrection?

Uh, about 250 an episode.

Well, I guess revolutions

aren't cheap.

-(chuckles) Right.

-LORNE: What, uh, what is this?

Absolutely not. No, no, no, no.

We're not gonna beg

for their approval.

No, take it down.

We don't need this.

Well, you know, Lorne Michaels

is a special bird.

You know, he believes

in his vision.

Well, that's nice.

Mm.

And he doesn't really bend.

We know how that story goes.

(laughs)

Mm-hmm.

CHEVY:

Des Moines.

-How'd you escape?

-(laughter)

Well, I appreciate you

saying that.

You know, my, uh...

my father had good taste,

and my mom was an alcoholic.

Excuse me, gentlemen.

Can I borrow him for a moment?

Enjoy the show, gentlemen.

You held that room like a pro.

(laughing)

Oh, thank you.

I mean it.

I'm Dave Tebet, head of talent.

You know, I handle

"The Tonight Show."

I didn't know that.

Between us, Johnny Carson isn't

gonna be around forever.

(Chevy laughs)

Think about it.

You're a handsome,

funny gentile.

That means something.

(sighs) Uh, Lorne,

you remember Dave Tebet.

LORNE:

Oh, of course.

I remember everyone

who gives me a job, d*ck.

Smart kid.

Quite a lineup this evening.

You know, while I have you,

I do understand

that we are bending

some of the rules...

Lorne, uh, this is NBC.

There's a way things are done--

the Peacock way.

Right, well, we are thinking

a little differently.

-We just, you know...

-Maybe an emu.

(laughs) Well, I just

really don't...

d*ck, shut the f*ck up!

Can't you see talent

when it's standing

-inches from your face?

-Mm-hmm.

What do you think

he's gonna do, embarrass us

with some half-assed,

rat-f*ck donkey show?

Frankly, that's exactly

what I signed up for.

M-Michael.

I expect you to be an unbending

force of seismic disturbance.

Light up that NBC switchboard

like a b*mb went off.

(laughs) Well, I promise

not to play the music too loud.

Ah, f*ck that. This isn't

Moose Jaw Jazz Festival.

It's "Saturday f*cking Night."

I want you to be

thunderous and deafening.

If my ears don't bleed,

I'll be asking for a refund.

Great. I-I mean, I've always

seen this as a collision

that erupts from

every screen in America.

-Yes. Yes.

-A prism that captures

the light of

an emerging generation...

Stop! Don't say another word.

Don't question

another instinct.

-Ebersol.

-Yes.

We're standing in the presence

of a prophet.

Yeah, he certainly

talks like it.

A man with a vision.

And I want you

to take that vision

like a Sherman tank

and plow through any f*ck

that gets in your way, even me.

(elevator bell dings)

"Use emotion for the many and

reserve reason for the few."

I like that.

I'm putting it on my wall.

-Was that a Hitler quote?

-(lively chatter)

Atrocities aside,

the man was a wordsmith.

Uh, you missed a call

from Johnny Carson.

-I-I picked up the phone...

-What did you tell him?

Uh, I told... I don't remember.

-He hung up on me, so...

-Lorne, Lorne.

Is that a bunk bed?

I did have a UFO encounter

experience once.

Danny ordered it

for his office.

That's confidence. Can you

find me something to eat?

d*ck: Neil, why would he

order a bunk--

-All right.

-(playing piano)

Could you get that hippie sh*t

out of my face?

And I'm actually very strong...

You think that

he can do the voice?

Uh, it's Aykroyd.

Of course he can do the voice.

It's Aykroyd, but that doesn't

necessarily mean...

Hello, boys.

-Hey, Mike.

-Hey, Mike.

-Are you nervous?

-Nervous about what?

Performing on live TV.

I'd be sh1tting bricks.

Television is merely

a lava lamp

with slightly better audio.

Colored beads

to fascinate the animal.

I could do it

in a narcoleptic coma.

Hello, Herb.

How's "Update" coming?

"South Vietnam

has seized and burned

a hundred thousand

'Playboy' magazines."

I'm still working

on the punch line.

"For miles, all anyone

could smell was roast bunny."

That's the one. Grab it, boys.

-Let's go.

-We need that couch.

-(Laraine and Gilda gasping)

-Rise and shine.

-Whoo! Okay.

-Coming through.

Coming through.

(laughter)

LARAINE:

Ooh, pages.

-Watch your back.

-Coming through.

-Oh. Here we are.

-This is...

You all right there, Chev?

Oh, things are, uh,

kooper kippy, Herb.

I think it just happened.

Think I got

the old shoulder tap.

The what?

You know,

from the guys upstairs.

What's gonna happen to me?

(chuckles) I mean, Herb,

you've been around the block.

Where am I going from here?

Well, I don't know, Chevy.

I never got a shoulder tap.

I just made a fortune

and won a few Emmys,

slept with Gloria Steinem.

Two out of three ain't bad.

GILDA:

Here we are.

LARAINE: Oh, wow,

you're in so many scenes.

Oh, yeah, but I'm always

everyone's kid sister.

You're the hot one.

I think Jane's the hot one.

No, I'm the mom.

The still f*ck mom.

(playing Elton John's

"Bennie and the Jets")

My instinct is that

the American people

are gonna fall in love

with you.

You'll be obscenely overpaid

for pratfalls and cute jokes.

You'll waste away

most of your life

with purchased company,

and then eventually

you'll self-medicate

with booze and hookers

and heroin.

I imagine you'll die alone,

falling out of a hotel room

window in Stockholm.

Jesus.

I can't wait.

Well, you're everyone's

favorite, Gilda.

Oh, I'm just a bagel

looking for lox.

I'm a parrot

with nothing to squawk.

Well, I keep feeling

like any minute

Lorne's just gonna

ship me back.

JANE:

Aw.

No, on this budget,

we can't afford the postage.

GILDA:

There's a reason you're here.

You may not know it,

but Lorne d...

-Oh, God!

-(Dan grunts)

You're dealing with a fully

qualified male strumpet.

GILDA:

I am not a prop, mister.

You know, I can assure you,

uh, professional hygiene,

discretion,

animal gratification.

GILDA:

Why don't you assure me

a little peace and quiet,

Mr. Strumpet?

MICHAEL:

You rang?

Yeah, I need the Muppet pages.

I already turned in

that one script.

Oh, was Henson uncomfortable

with the Muppets

on a plantation?

It was a musical number.

I don't think

that's the problem.

I just can't write for

those little hairy facecloths.

Well, I need something for

Henson. We go live in an hour.

You cannot say "horny" on NBC.

Did you see what

that evangelical c**t did

to our pages?

I'll be right back.

FRANKEN: So you want us to say

"sexy" instead of "horny"?

"Sexy" and "horny"

just don't mean the same thing.

I struggle to see

the difference.

Well, if a dog is humping

your leg, it's horny.

It's certainly not sexy.

What on earth are you doing?

I'd rather butt-f*ck cancer

than make these changes.

-(window opens)

-(horns honking outside)

(sighs)

Your words don't scare me,

Mr. O'Donoghue.

I am a woman of God.

I'd heard God's love is blind.

-Now I know why.

-(laughs)

You see this?

I do.

I know it looks like

an ordinary red marker,

but this one is special.

It has kept America safe for

the better part of a decade.

It is a weapon

against vulgarity,

sex, communism and hedonism.

Oh. What about violence?

Does it protect America

from violence?

Yes. That, too.

Oh, how about infanticide?

Excuse me?

Apologies.

Just a, uh, two-dollar word

for a parent

who kills their own child.

(scattered laughter)

The mere thought

makes me nauseous.

Oh, understandably.

Me, too, by the way.

It's just,

I had this idea for a sketch,

and I'm not sure if it's

funny-- you can be the judge.

It's about this powerful,

temperamental guy

who r*pes this virgin

in the middle of the night.

I know. Awful.

Knocks her up

without ever saying hello,

-buying her flowers, whatever.

-(snickering)

And then... then--

here's the funny part--

he has their b*stard son

publicly mutilated

and tortured to death

on a cross.

(scattered laughter)

You are a vile human.

Ah, f*ck.

You've heard this before.

(laughter)

Mr. O'Donoghue.

Are we still being formal?

Please, just call me Satan.

-No, I am Satan.

-I am Satan.

-LARAINE: I am Satan.

-JANE: I am Satan.

-I'm Satan.

-No, I'm Satan.

You will be forgotten.

I am gonna make sure of it.

DAN:

Well, we're Satan.

Bye.

(laughter, murmuring)

Are you out of your mind?

MICHAEL:

Look, for better or worse,

-I call it like I see it.

-That was worse.

Lorne, they need you

at the loading dock.

I'm sure someone can sign

for whatever.

-You're back on the Muppets.

-f*ck you.

-I'll quit.

-Yeah, I doubt that.

It's-it's Leo. He's been

fighting with security,

and there's blood.

(sighs) d*ck.

(sighs) Oh, sh*t.

DAN:

Satan.

-LORNE: Ah.

-d*ck: Hey.

-LORNE: Hey, d*ck.

Is this turkey? -(chuckles)

-d*ck: While I have you...

-Uh, there wasn't a sign, so...

-Great. -Lorne, Lorne,

while I have you,

uh, I know you always want

to be on the cutting edge.

Check this out.

Polaroid.

Okay.

Uh, we can have the actors

demo it live,

write it into sketches,

uh, do live commercials.

Funny ones.

The payout is bonkers.

d*ck, the cast didn't sign up

to do live commercials.

Neither did I.

Some of the cast

might find that very unseemly.

Mm-hmm. I completely

understand, but, uh, uh,

television's driven

by advertising.

It's what makes the motor run.

It's really not

a big deal at all.

Just please don't show this

to the talent.

I don't want them thinking

they're back

on "The Kraft Macaroni Hour."

Neil, what,

are we going kayaking?

What is this?

Uh, Lorne, we're over budget.

d*ck, you don't need

to tell me that.

Someone needs to tell you that.

We don't even know

what the show is yet.

How could we possibly

know the budget?

That's true. It's a good point.

Neil, please!

If we don't know

what the show is,

uh, Lorne, what the f*ck

are we doing here?

I know the ingredients, just...

-just not the amounts.

-Lorne, what does that mean?

-Just have to make it to 11:30.

-GUARD: I'm gonna f*ck you up!

-Hey!

-(grunts)

Ah, f*ck! You fascist.

LORNE:

You want to lose your job?

You want to lose your teeth?

I'm the producer

of "NBC's Saturday Night,"

and you just hit

a man with a Tony.

-LEO: f*ck you.

-I've hit plenty of Tonys.

All right, hey, that's enough.

GUARD: Tell your friends

no deliveries after 6:00 p.m.

-MAN: Walk away.

-All right.

-LEO: Shove it up your a*s.

-GUARD: f*ck you.

LORNE: All right,

keep coming with the bricks.

You took that punch

like a champ.

I'm actually not sure

you're supposed to be

pinching the bottom

of the nostrils.

If you pinch a little higher...

-Hey, guys, I'm so sorry.

-NEIL: Any higher, it's bone.

Am I missing something?

Why are we using real brick?

Can't we just roll out

linoleum?

-Hey, f*ck you!

-d*ck: Okay, whoa. Just relax.

d*ck, our vision for home base

is a street corner

with all the grit and texture

of New York City.

Yeah, okay, but are...

I mean, are we gonna use

-real blood and vomit, too?

-LEO: I'll give you some

-real f*cking blood. -Hey, hey.

Whoa. No more fighting.

-No more fighting. He doesn't

know. -d*ck: Whoa. Relax.

He doesn't know. It's okay.

-LEO (sighs) Oh, my God.

-(elevator clanking)

Wh-Why are we stopping?

-Hello, everybody.

-LORNE: Andy.

-d*ck: Why is Andy on another

floor? -LORNE: What are you...

You can't keep

wandering off like that.

Mr. Michaels,

I had to go to the bathroom.

-That's very good.

That's very good. -d*ck: Lorne.

LORNE:

Barbara, what time do you have?

Uh, 10:39.

-Lorne.

-LORNE: Hmm?

The brick.

It's... (sighs)

It's got its pockets out.

It's workmanlike. It's honest.

d*ck, it's critical

for the success of the show.

Okay, but what is the show?

(sighs)

I mean, honestly, d*ck,

if you don't know by now...

(elevator clanking)

DON:

Chevy Chase.

Gilda Radner.

Dan Ike-a...

How the f*ck

do you pronounce it?

Aykroyd.

-Dan Aykroyd.

-50 minutes, everybody!

-DON: Laraine Newman.

-GARRETT: So, you nervous?

Uh, no, not really.

I mean, I've only got

a couple bits.

The... the jury thing

and a TV host.

GARRETT:

Uh-huh.

Say, uh, you ever wonder

exactly what it is

you are doing here?

Yeah, and I think

I've got a pretty good idea.

And what is that?

Well, Garrett, I'll tell you,

I like to give

a hundred percent

in everything I do.

And I like a dish soap

that does that, too.

So alive, so young,

so alluring, so exotic,

so hypnotic, so manipulative,

so sadistically a*usive,

so cartoonishly abhorrent.

You see, when it comes to

my skin and my sensitive parts,

I only trust

100% American-made steel wool.

-(coughing)

-Strong enough for a man

but whimsical and helpless

enough for a woman.

Don't wait. Act now.

Act like your very life

depends on it.

Act like your children's lives

depend on it.

Act like the children

in Africa's lives depend on it.

-And what the f*ck was

all of that? -(laughing)

That was my 20s, Garrett,

and that is exactly

what I'm doing here.

Well, sh*t.

I'm just here to play,

uh, the butler,

the shoeshine guy and the pimp.

Think you seem a little nice

for a pimp.

And you're a little pretty

for a comedienne.

Well, cheers to staying out

of the spotlight.

-GARRETT: Mm.

-(lights clunk)

DON: Ladies and gentlemen,

your host,

-George Carlin!

-(sniffs)

Can't just let me come out from

behind the g*dd*mn curtain.

I have to descend

like Norma f*cking Desmond.

All right. f*ck you, everyone!

f*ck you. f*ck you.

I've definitely f*cked you.

-f*ck you.

-Yeah!

f*ck you, and f*ck all of you.

-You have to distract her.

-How?

With your sparkling wit.

Uh, excuse me, miss.

Uh, could you confirm that

this is a normal deck of cards?

No marks, no folds,

no blemishes?

-JOE: George!

-Yeah. All right.

(clears throat)

Welcome to the show.

I have some music, some laughs.

I plug the record.

Blah, blah, blah.

...regular old deck

of 52 cards.

I am going to...

JOE:

George, keep going, please.

GEORGE: Yeah, yeah, yeah.

You ever look at

the crowds in old movies

and wonder if they're dead yet?

Slow, slow, slow!

Are you f*cking kidding me

with this sh*t?

JOE:

And throw to Janis.

What?

Yeah, throw it to Janis.

Introduce her, please.

Keep going.

Ladies and gentlemen,

J-Janis Ian.

I learned the truth at 17

That love was meant

for beauty queens

And high school girls

with clear-skinned smiles

Who married young

and then retired...

-Mr. Carlin.

-Yeah.

I'm Joan Carbunkle,

NBC Standards.

GEORGE:

Oh, I didn't know they had any.

LORNE:

Joan, he's very busy.

Just please share your concerns

with me, all right?

No, no, no, no, I-I'd like to

hear her concerns personally,

if you don't mind.

I know you have a propensity

for the obscene

and a lurid interest

in colorful language.

Thank you very much.

Mr. Carlin, you'll be happy

to know that there is

one delay button,

and my finger is on it.

With ravaged faces,

lacking in the social graces

I'm surprised you even

found the button,

let alone touched it.

Desperately

remained at home

Is this your eight of diamonds?

Inventing lovers on the phone

who called to say

"Come dance with me"

And murmured vague...

Are you gonna help?

I really wish we could,

but, uh, we don't do bricks.

What guild is it

that does the bricks?

-Is that 422?

-No, that's carpenters.

How about 303?

Nah, that's the pipe fitters.

(laughter)

I don't know why

you're laying brick.

You're gonna be gone

in two weeks.

A brown-eyed girl

in hand-me-downs...

So, it's gonna be like one of

those 1950s safari flicks.

You know the ones with

Rhonda Fleming, Susan Hay...

What the... Th-That's a prop.

So I want you to take this bowl

of potato chips here.

-Me?

-Yes, you.

-I want you to reach into them.

-Okay.

Every time I take a step,

give them a little crunch.

All right? It's like

we're in the safari.

-Ready?

-(Andy chuckles)

Give it a try.

(crunches)

(chuckling)

-(crunches)

-Early.

I just got this job.

-(crunches)

-Now we're getting it.

(repeated crunching)

(laughing)

You piece of sh*t.

-(crunching stops)

-That was nice.

Not bad.

(crunching resumes)

-ANDY: Oh. (giggles)

-(clicks tongue, spits)

ANDY:

Caw, caw.

-(hooting)

-Don't sh**t me.

-Caw.

-(Valri chuckles)

Caw, caw.

-CRYSTAL: I know that noise.

-(Andy hooting)

That's a monkey being run over

by the C Train.

(hooting continues)

CRYSTAL:

My archnemesis.

Here he comes.

(hooting stops)

There's no way they're gonna

fit all that show.

You think?

CRYSTAL:

Yeah, something's got to go.

Hey, Lorne,

can we talk minutes?

LORNE:

You're doing great, Billy.

-VALRI: That was weird.

-Yep, we're f*cked.

-(sewing machine rattling)

-GARRETT: Mm-hmm.

(sniffing)

Excuse me, "Ossifer."

Have I done something wrong?

What do we have here?

Why, that would be my a*s.

Mm-hmm.

Billy Preston's band

hooked it up.

Medical-grade, baby.

Floats in the bottle,

and then...

(snorting)

Checks out. (sighs)

Medical-grade.

Uh...

So, tell me how you fit

into this, uh, ensemble.

Oh, is this an ensemble?

Uh, no, we have many, uh,

-talented, talented improvisers

-(spray can whooshing)

from Chicago

and Toronto and, uh...

-JACQUELINE: And Boston.

-CHEVY: And Boston.

Yes, Jane Curtin

is from Boston.

-You met my fiance. (laughs)

-(sniffs)

Missed a little there.

Uh, but to answer

your question...

LORNE:

While I've got you c*ptive...

-They want to shave me.

-CHEVY: Oh, careful.

There's no jaw

under that beard.

-Just ten pounds of neck.

-LORNE: Chevy.

CHEVY: Uh, I'm pretty sure

you'll be seeing...

-(clattering)

-Jesus Christ, you psycho.

-You son of a b*tch.

-LORNE: Whoa, whoa, whoa.

CHEVY: Throw that

one more time, I'll shove it

-up your f*cking a*s!

-LORNE: Hey, hey. Hey, hey!

Whoa, whoa. Hey, hey, hey.

Hey, stop right now.

JANE:

Guys, come on.

-Cut it out right now.

-g*dd*mn it, stop!

Stop! Chevy, out.

Don't feed coke to the animals.

LORNE:

Out! Chev.

(John panting)

JANE:

Take a seat.

ROSIE:

You okay, John?

-So we're throwing things now?

-He started it.

It's just a shave, John.

So NBC owns my f*cking face?

-ROSIE: No.

-LORNE: Yeah, a little bit.

Would Jimi Hendrix play

in mittens?

That's a good point.

John, you're going to go down

as one of the giants

of character expressionism,

from Chaplin, Brando...

Belushi.

LORNE:

Why hide your gift?

Beards are for pussies.

The bees are bullshit.

You think I don't know that?

Of course they are.

They're stupid.

They're postmodern.

They're Warhol. They're iconic.

They're-they're Sgt. Pepper.

-ROSIE: So well said.

-LORNE: I'm glad you get it.

John, we go live

in less than an hour.

45 minutes!

-(Janis continues singing

in distance) -(clicks tongue)

I need you to sign

your contract.

(John scoffs)

(feedback squealing

in distance)

-Oh, yeah.

-(singing stops)

(electrical buzzing

in distance)

What? What's happening?

What happened to the music?

Hey, what...

wh-why'd you stop playing?

The speakers went out.

-All of them?

-All of them.

What the hell is happening?

What... d*ck.

I'm on with the outfit

that supplied speakers at...

-Yeah, Rockefeller Plaza.

-LORNE: Toscanini!

Height of audio fidelity.

What can we be doing?

Uh, yeah, what can we be doing?

We got no sound,

idiot on the light board,

and we go live in 45.

What do you want to rehearse?

-Uh...

-(Lorne sighs)

-We could pull up...

-Do you want to do...

-"Weekend Update"?

-"Weekend Update"? Yeah.

All right, everyone, we're

moving to "Weekend Update"!

-Okay, great, great, great.

-Don, stand by for your intro!

(busy chatter)

JOE:

Here we go. Move it, people.



CREWMAN:

Let's go, let's go!

LORNE:

I'm good. Fine.

CREWMAN:

All right, let's go.

Last looks, everyone.

DON: From "Saturday Night"

News Headquarters,

this is "Weekend Update"

with Lorne Michaels.

(takes deep breath,

clears throat)

LORNE:

Our top story tonight.

Some world news:

Japanese Emperor Hirohito

met Mickey Mouse

at Disneyland this week.

The emperor presented Mickey

with a Hirohito wristwatch.

Oy.

(someone coughs)

(forced chuckle)

LORNE:

How was that?

It was horrible.

Right. Um...

And now with a weather report,

we turn it over

to meteorologist John Belushi.

What's it looking like

out there, John?

Thank you, Lorne.

Uh, it's often said

March comes in like a lion

and goes out like a lamb.

But did you know March behaves

differently in other countries?

In Norway, for example, March

comes in like a polar bear

and goes out like a walrus.

Or consider

the Republic of South Africa,

where March comes in

like a lion

and goes out

like a different lion.

-(laughter)

-Like, one has a mane,

and the other

doesn't have a mane.

And there's a country where

March hops in like a kangaroo

and stays a kangaroo

for a while.

-Australia.

-JOHN: Then... then,

for a couple days,

it's sort of a cross between

a frilled lizard

and a common house cat.

Then it changes back

into a smaller kangaroo,

and then it goes out like a...

like a wild dingo.

Now, now,

and it's not Australia!

You'd think it'd be Australia,

but it's not!

-Oh.

-(laughter)

And there are nine

different countries where March

comes in like a frog and goes

out like a golden retriever!

But that's not the weird part!

No, no, no, no,

the weird part is the frog!

The frog! The weird part is...

(grunts sharply, shrieks)

(laughter)

(laughs) Okay.

(laughter, applause)

-(grunting)

-You all right?

Are you okay?

-I give in.

-That was brilliant.

Now I need you

to sign your contract.

(grunts)

-Was that a yes?

-That was a yes.

-Was that a yes? Okay.

-That was a yes.

-Uh, Neil, can I get

the contract? -NEIL: Yeah.

-Okay.

-LORNE: Do you have a pen?

NEIL:

Uh, uh...

BARBARA: Lorne, Lorne, Lorne,

there's a call from Burbank

waiting in your office.

Burbank. Carson.

Uh, okay.

Um, someone get him a pen.

Don't let him use it

as a straw.

Uh, rehearse something.

Anything.

All right, uh, "Bee Hospital,"

stage left.

-Let's go. We're moving.

Here we go. -(bell ringing)

-Great work, guys.

-HENSON: Excuse me.

Hey, Mr. Michaels.

-Oh, Mr. Henson.

-Hey.

I'm excited to see what you and

your merry band of creatures

have in store for us tonight.

Well, Lorne, uh, we don't have

any script pages yet,

so, uh, the Muppets

are flying blind here.

Well, this is the first

I'm hearing of it.

-Neil, Jim needs his pages.

-HENSON: Thank you, thank you.

And please, uh, sorry, Lorne.

Can you please remind your crew

not to leave the Muppets

in compromising positions?

That doesn't sound like them.

Well, they left a note.

They didn't.

They did.

It said...

"f*ck-rags for rent."

-Mm-hmm.

-Okay?

I know what that means, so...

I'll... I'll talk to Michael.

-Immediately.

-Thank you.

(laughing)

All right. Thank you.

Oh, hey, Bernie.

Oh, no, you're good.

(takes deep breath)

Hello. This is Lorne.

CARSON (over phone):

I, uh... I was beginning

to think you didn't like me.

Of course not, Mr. Carson.

You're the voice

of a generation.

CARSON: I, uh...

I just wanted to reach out

and say good luck tonight.

LORNE:

Oh, that's very kind.

CARSON: And also, I suppose

I wanted to make sure

we don't end up stepping

on each other's dicks.

-Right.

-You know how this all started,

-don't you?

-(softly) Just sign it, John.

Just sign it, John.

With a kite and a key,

I'm sure.

CARSON: Don't be a dipshit

for a second, kid.

I'm sure you've heard by now

that Mommy and Daddy

are fighting

and that's why you've got

the house to yourself tonight.

Frankly, it's the only reason

they'd ever green-light

your little talent show.

Look, these things always

go the same way.

First they try to f*ck you,

-and then they buy you dinner.

-Oh.

CARSON: I'm not opposed

to "Saturday Night."

-Whoa, whoa, whoa.

-Even if it is a dumping ground

for the d*adbeats and bagheads.

-d*ck, no.

-CARSON: In the meantime,

you get to play dress-up

on national television.

-LORNE: Don't let him hold the

camera. -CARSON: Good for you.

So, here's some

friendly advice.

Enjoy your little show,

but don't get too comfortable.

You're a benchwarmer,

a stalking horse.

It's my f*cking network.

It's my f*cking night.

-(clattering)

-No hard feelings, though.

JOHN: f*ck the bees,

and f*ck this show!

JOE:

John, hey. Where you going?

-I go where I'm kicked!

-JOE: John.

CARSON: Heard you are

a halfway decent writer.

Uh, send me some samples

sometime.

We're always looking

for a punch-up.

(phone clicks)

How'd the call go?

Tremendous.

Thank you for asking.

-Oh, great.

-Belushi walked.

What? He quit?

No. Well, technically, he would

need a f*cking job to quit,

but yes, he walked.

We need to find him.

I'll take the eighth floor.

You take the ninth. Okay?

Uh... oh, okay.

Uh, hey, have you seen

John Belushi?

JIM FOX: We cannot broadcast

directly from 8H.

Um, sorry, Jim.

Have you seen John Belushi?

You want to hand the airwaves

over to that maniac?

NEIL:

Have you seen Belushi?

I'm not an animal wrangler.

Belushi? Belushi?

-Belushi?

-Belushi?

Belushi?

-Belushi?

-Belushi?

Hey, have you guys seen

John Belushi?

John?

(quiet chatter)

Hey, guys, sorry to bother you.

Have you seen John Belushi

anywhere?

Oh, yeah, sure.

He was, uh, hanging out with us

yesterday, right, Howard?

No, sorry, I meant

in the last few minutes.

Oh. No.

You seemed stressed.

-You okay, buddy?

-Yeah.

You need a... you need a hit?

Uh, oh, no, no, no.

That's-that's fine.

-That's okay.

-Oh, I...

think it'd help.

That makes sense.

There we go.

Oh, look at him.

Attaboy.

Good luck on your quest, amigo.

(coughing)

Have you seen John Belushi?

Have you guys seen John?

Uh, Neil,

who do you think I am?

Human bumblebee.

No, man, I am talking about:

(voice distorting) What is

my identity on the show?

Don't ask me that right now.

I can't answer that right now.

Oh.

(chuckles)

-Oh. -(distorted)

What the hell are you doing?

Oh.

(ice rattling loudly)

Thank you.

Sorry.

Has anybody seen John?

-I'm John.

-I'm John.

-No, no, no, no.

-OTHERS (echoing) I'm John.

-Hold this, please.

-(ice rattling loudly)

TOM and FRANKEN

(echoing, repeating) Belushi?

NEIL: Hey, have you guys

seen John Belushi?

Hey, kid, why are you holding

your face like that?

-Why you shouting?

-Oh, sweetie, are you okay?

I don't know.

I-I-I can hear my own blood.

-Am I gonna be okay?

-Don't ask her.

She's a nymph,

not a nurse, kid.

-I know that!

-Whoa.

-Look, should I be worried?

-About Neil?

No, f*ck Neil. About my act.

I can't get a straight answer

out of Lorne.

Billy, you're family.

-Uh, Neil...

-Neil.

ANNOUNCER (over TV):

This week on "The Rumpus Hour,"

Tony Orlando and Dawn,

Shields and Yarnell,

the Domingo Brothers,

and your favorite juggling

barbershop quartet,

Macho Quatro.

Lorne.

-You know Milton Berle?

-Oh. Absolutely.

Big fan.

I grew up on your work.

Who didn't?

Hear it's your big night.

Planning on it.

How's it all coming?

Just perfect.

-You never hear that.

-You certainly don't.

Yep. Being here must bring back

all kinds of memories,

I'm sure.

Sure, sure, yeah.

Used to call this

the RCA Radio Tower.

Radio, that wonderful invention

by which I could reach

a million people

who, fortunately,

couldn't reach me.

You know, Milt's TV show

once pulled a 97 share.

97% of the American audience

was watching Uncle Miltie.

Do you ever miss being

Mr. Television?

What is he talking about?

Lorne, Milton remains

one of the Peacock's

most colorful feathers.

-It's quite a feather.

-Of course. Of course.

And I'm looking forward

to hosting your show.

Well, well, we'd be honored.

Uh, I think there's still

so many decisions

we'd have to make.

MILTON:

I'm hearing episode five.

TEBET:

The boys upstairs love it,

and the affiliates ate it up.

MILTON:

Well, they're the real boss.

LORNE:

Right. Well, it is a late show.

Are you suited for midnight?

(chuckles) At 67, I still

feel like a 20-year-old.

Unfortunately,

there's never one around.

-(Tebet laughs)

-Your reputation precedes you.

Yeah, by about 11 inches.

Excuse me a second.

TEBET:

Any sign of Belushi?

Uh, John?

I believe he's in wardrobe.

Why?

Legal is frantic

for his paperwork.

That's strange.

I'll look into it.

Lorne, I can only imagine

what must be running

through your mind:

the thought,

no matter how improbable,

that you might not

make it to air.

-Hadn't even occurred to me.

-Really?

I heard that you were having

some technical difficulties.

None that I know of.

-(clattering)

-What the f*ck?

I just heard that

your writers were stoned,

your actors were physically

assaulting each other...

-(clamoring) -...the sound

system was down...

What the hell is happening?

What...

...and a fire broke out

earlier.

(clamoring)

I've been doing this job

a long time.

I've seen it all.

I'm sure you have it all

under control.



Minor issues,

already addressed.

That's reassuring.

Oh, this whole conversation is

a soothing shower of relief.

Good, good. Look.

If, for some reason,

you can't lock your script

or commit your cast

to legally binding contracts,

rest assured,

the country will be happy

to watch "Johnny Carson."

Well, we could always play

the tape of dress rehearsal,

worst-case scenario.

That's not the worst case.

(knocking)

-(quiet chatter)

-(Tebet sighs)



VALRI:

f*ck me, that's a lot of cards.

Yeah, what's the fastest you

can do your set, top to bottom?

-Five minutes.

-Yeah. Me, too.

-Could you do it in four?

-Probably.

Yeah. Me, too.

So, look, they're gonna

offer us three,

but we got to draw the line

at four, all right?

Okay.

I want to do the show.

Oh, yeah, we're doing the show.

We just can't get

jerked around.

-That's all.

-But we're doing the show?

Of course we're doing the show.

We just got to be

in this together.

Okay.

-Neil, sweetie, is everything

okay in there? -Hello!

Oh, my God.

Special delivery for Neil Levy.

-Flowers! Candygram.

-What's with the kvetching?

-Neil, uh...

-Neil, it's your mother!

-Open the door!

-(clamoring)

-A boy becomes a man.

-Come on out.

Come on out, Neil. It's okay.

-Hey, Neil, buddy?

-It's safe out here.

-You freaking out in there?

-Oh, God.

NEIL: I took a hit

in the departure lounge.

-All right. Whose grass was it?

-(Chevy whistling)

-One of the horn players.

-Oh, degenerates.

Well, that's a potent dragon

you're riding there, kid.

What you smoked was

a sacred strain

from the Isaan plateau

of Thailand, I believe.

-The best plateau.

-Make no mistake about it,

that stick's probably stronger

than a bull elephant,

but, uh, listen, we're all

a little freaked out, so...

-I'm freaked out.

-...why don't you come out

and, uh, we can...

we can check on your face,

make sure it's not

inside out, okay?

-Come on, Neil.

-Show us your face, Neil!

-Show us the face!

-Come on, bud.

-Show us the face.

-Aw. -Oh...

-(shouts)

-(laughter)

Oh, no, no, no, no, no, no.

I'm just kidding.

Look, you're gonna be fine.

We'll fix you up

with some amphetamines.

You'll be fit as a flea.

Might even like the stuff.

Cocaine.

Robert Louis Stevenson actually

did some of his best writing

-on the nose candy.

-Oh, Bobby.

Not a lot of people know that.

Yeah. He was a big freak

for the Peruvian Lady.

Hey! We need everyone in togas!

Everyone down

to the eighth floor now!

(all whooping and hollering)

I'm not in a toga! (screams)

(laughter)

(whooping and hollering

continue)

Wait, what? Oh, oh, okay.

Okay, but why are we yelling?

JOE: Cast, got new pages.

Take a look.

WILSON:

Rocky, there's no way

these kids are gonna

hit their marks,

so you better be wide enough

to catch them all.

-We got that?

-Hey.

Did Rosie tell you

what she wants for her credit?

Oh. Uh, she was of two minds.

What is this? Why are you

cuing up "Carson"? Who is that?

d*ck:

I think that's Tony Curtis.

That's pretty normal

right before a live show,

right, Dave?

Yeah, if anything goes wrong,

we bump the tape.

-See?

-R-Right.

Lorne, Lorne, we found

a lighting director.

LORNE:

Great. Go get him.

Well, no, he's lighting

a show right now.

-This will take some massaging.

-(sighs) We don't have...

What floor?

It's down on the sixth floor,

some variety show.

And he knows I'm coming?

Uh...

-Uh, say, Lorne,

this a bad time? -Huh?

-Perfect time, Garrett.

-Okay, I've been thinking.

Why did you hire me?

-You were cheap.

-Really?

I'm being ironical, Garrett.

The f*ck?

(inhales deeply, exhales)

Hey, Garrett. What's wrong?

(sighs)

Oh, nothing. I'm just, um...

just trying to figure out

exactly what it is

I am doing here.

Aw. What do you mean?

Oh, you know, I just...

I just can't help but feeling

a little bit like an outsider.

-Because you're so much older?

-What?

I went to Juilliard.

I've been on Broadway.

I'm a published playwright.

Man, they got me buzzing around

here in a g*dd*mn bee suit

and waving a g*n around

like I'm some kind of hoodlum.

These are not

my strengths, man.

I am being underutilized.

Which makes me ponder--

what am I doing here?

You know how many operas

I've done?

-I have no idea, Garrett.

-sh*t.

While Danny and Laraine

were eating Froot Loops,

I was performing "La traviata"

in Italian.

You dig?

Of course. I-I dig, Garrett.

But, uh...

no one is saying

you can't sing on the show.

Right?

(sighs)

(elevator bell dings)

Where's the "Rumpus" room?

Down on the right.

(blades scraping)

Whoa, whoa. Pardon me.

(tap shoes clacking

rhythmically)

(bell ringing)

-Whoa, whoa, whoa.

-PRODUCER: And three, two...

("La Cumbia del Muerto" by

Mariachi Tenochtitlan playing)

PRODUCER:

And we... seven, eight.

And walking.

Five, six.

Uh-oh.

Smile.





(music continues,

muffled and distorted)

Hey! f*ck.

Get your head out of your a*s.

Prep the cupcake lights

and bring up the glitter, Carl.

Carl?

I have a job offer.

Comes with no guarantees,

no perks and no weekends.

How's the pay?

That's the worst part.

What the f*ck?

-When do I start?

-LORNE: Right now.

LIGHTING DIRECTOR:

Yeah, send me a postcard

from the gutter,

you little sh*t.



(song ends)



(quiet chatter)

Rosie, you seen Jackie?

No. Sorry.

(singsongy)

Knock, knock.

-Hi.

-Hi, stud. Can I see?

Can you get Chevy

to do this one?

Ooh. No way.

You look so sexy.

(groans) Th-These can't be

the right size.

Yeah, you're right. They should

be a little bit smaller.

DAN: Ah. Just feels like

it's a lot of leg.

ROSIE:

Are you kidding, hot stuff?

You're gonna melt every TV

in America.

-Oh, yeah?

-Oh, yeah.

You know, ma'am, you're dealing

with a fully qualified

-male strumpet here.

-ROSIE: Oh, "ma'am"?

DAN:

I've actually got a work order

stating I should be

rogering you roundly right now.

-(laughs) Stop it. -LORNE:

Hey, have you guys seen John?

Um, uh, no, I haven't seen him.

-(Dan clears throat)

-Danny?

-Yeah?

-BOTH: Have you seen John?

John. Uh, well,

John's an anarchist

and an Illinois alpha male.

Wh-What does that mean?

Oh, uh, well, see, boss,

you and I, if we were

to enter this space,

we'd be like

15th-century peasants

walking into the Vatican, but

Belushi's a whole other animal.

He's a skeptic and a sinner.

I'd give O'Houlihan's a recce.

-He's at the bar next door.

-LORNE: Ah.

Um, Barbara's still asking

about your credit on the show.

-ROSIE: Whatever you think.

-It's your name, Rose.

(sighs)

Has he only gotten that far?

We'd like to help, but, uh,

we're rooting for the guy.

Well, at least

your heart's in it.

Hey, you seen Jacqueline,

my fiance?

-No, I haven't seen sh*t!

-(laughter, indistinct chatter)

-Ladies, have you seen Jackie?

-No.

All right, change of plan.

We're skipping ancient Greece,

and we're moving

into the break room.

Ladies, I need you

in your hard hats.

-(groaning)

-Okay? Right now. Come on.

-I don't want to change.

-(squealing)

-Are we good? 'Cause, uh...

-(stammers)

-Is he all right?

-Yeah. Yeah.

Danny, I mean, whatever's

going on between you and me

is the last thing

on his mind right now.

So the man doesn't wrestle

with the green-eyed monster?

Hardly. I mean, look,

I've known Lorne

since I had toilet paper t*ts.

One day, he just

followed me home from school,

-and I never shook him.

-Hmm.

-Pretty sure you can be

arrested for that. -Yes.

-Look out, Rosie!

-Oh, sorry, Moose.

Anyways, I don't know.

Lorne lost his dad

when he was 14,

and his mom sold everything,

and so he spent a whole year

without furniture.

So when I first met him,

I thought,

he's just a stray looking

for a spare piece of carpet.

Like, he wants to be

a part of my family,

and I'm the kid sister

or something.

But then hormones.

Turns out

I'm not the kid sister.

And so we start dating,

and I think,

"Okay, he wants to build

a family with me."

And we get married,

we buy a house.

I mean, no ring-- I think

those are pretty stupid--

but linens and china.

And then it turns out I'm not

the kid sister or the wife.

So who are you?

I'm the writer.

-JOE: All right, rehearsal's

moments away. -DAN: Ah.

-JOE: Here we go.

-DAN: And, uh, who's he?

-We take you now to

ancient Greece. -Okay, girls!

-Whoa, whoa, no, not yet, Don.

-Gilda, can I get you

-behind the lockers?

-It's the wrong sketch, buddy.

-Okay.

-Yeah.

And try sitting like men.

-Oh, yeah.

-ROSIE: Perfect. Okay.

Hair and makeup, clear.

Clearing.

Please get the f*ck out.

Thank you.

Okay, and action.

(locker bangs shut)

Now that you've mastered all

the, uh, technical know-how,

I think it's time we work

on your sidewalk skills.

-All right.

-(light laughter)

GILDA: Daniel over here

has kindly offered

to aid us

in a live demonstration.

Come on out, Danny.

Danny, enter.

(someone clears throat)

-(laughter) -ROSIE: No,

you got to take off the robe.

I can lose it on the day.

I figured I'd rehearse with...

No, you can lose the robe

right now.

(laughter, whooping, whistling)

-The shorts are too short.

-ROSIE: Oh!

Now, when a little piece of

heaven like Danny walks by...

-Little strut?

-...here's how you make him

-feel right at home.

-Right. (clears throat)

-Voom, va-va, voom, va-va.

-(laughter, whooping)

Show him how you do it, Gilda!

GILDA: Okay, come on, Jane.

Give it to him.

-All right. -ROSIE: Rocky,

can you get a close-up?

Hey, dreamboat.

What's the matter?

Why don't you give me

a little twirl?

Show me what

you're working with, huh?

(others whooping, hollering)

GILDA:

Okay, give it to him, Laraine.

Hey, stud muffins.

Want to make bouncy-bouncy?

(laughter)

Are we still

doing the scene or...

What are you talking

to her for?

You're talking to me,

joy chunks.

ROSIE:

Stay in character, please.

-Hey. -GILDA: Come on, baby!

-JANE: All right.

LARAINE:

You dropped something.

OTHERS:

Oh...

Well, I guess I should just

pick this up.

-Oh, you better get it!

-(laughter, whooping)

Yeah, give it to him!

-Give it to him!

-Oh!

All right, all right.

All right.

They are so cute

when they're mad!

DAN:

All right. Thank you.

Okay, cut.

(whooping continues)

The shorts are... the shorts

are too short. I told you.

Here you go.

It was a great scene.

Yeah, strumpet.

JOE:

All right, everyone, moving on.

Great rehearsal. Here we go.

We take you now

to ancient Greece

as Alexander the Great

attends his ten-year

high school reunion.

Hey, boys,

have you seen Jackie?

Gentlemen, you seen Jackie?

(busy chatter)

-(Jacqueline laughing)

-MILTON: Oh, look at that.

-My goodness. -Hey, hon,

they need us in Athens.

Jesus. Who's this guy?

Chevy, Milton taped a show here

back in 1956.

-Isn't that neat?

-Oh. She's taken.

What hours? I'll take

the rest of the evening.

-Excuse me?

-JACQUELINE: He's kidding.

-Yeah, buddy. I'm kidding.

-CHEVY: Oh, that's cute.

I remember when

you used to do comedy.

Ah, funny,

'cause I never heard of you.

That's probably

the Alzheimer's.

What's the matter,

did you wander off

-onto an actual TV set?

-(Milton chuckles)

CHEVY: Hey, darling,

you're sitting in front of

the Ghost of Television Past.

This old man, he...

he used to be an institution.

Now he needs one.

If you want my comeback,

you're gonna have to scrape it

off the back

of your mom's teeth.

(laughs) Jesus.

You're gonna laugh at that?

MILTON:

Listen, sweetheart.

There's plenty more

where that came from.

(pants unzip)

God.

Oh.

Do I have your attention?

(chuckles)

I have two stars

on the Walk of Fame.

-Oh. Mm.

-Oh, yeah, who gives a sh*t?

I once held 97% of America's

television viewing audience.

Eh.

That's not what

they're gonna remember.

They're gonna remember

Mr. Television,

their Uncle Miltie.

Who the f*ck are you, kid?

You're not a star.

You're barely in

the f*cking building.

(chuckles softly)

You're not even

a swinging d*ck.

(pants zip)

Call me after he's done crying.

GEORGE:

Are you sh1tting me?!

Are you sh1tting me

with this costume?

Can you make a path? There's an

actual comedian coming through.

Oh, wow. Look at these columns.

I feel transported. Oh...

-Hey, George. How can I help?

-Yeah?

So... so, what-what is...

what is this?

Why am I dressed like a f*cking

towel boy from Caesars?

Well, I believe you're

Alexander the Great at his,

-um, ten-year high school...

-Ten-year high school reunion.

-Thank you, Don.

-MICHAEL: Exactly.

So when Chevy asks

what you've been up to,

your response is,

"Ah, you know,

mostly, you know,

conquering the known universe."

Right. And-and this is

for television?

-Mm-hmm. What's your concern,

George? -Right.

My real concern is

why I let my agent

convince me to do your show.

Do you need some help

with the script?

I'd just love to know

where the humor is.

It's like a Spruce Goose.

It's a lot of wood

and no liftoff.

-Is that right? -Well, we can

rewrite. I mean, we have...

Jesus Christ, we could...

we could find...

No, no, no. George, I hear you.

LORNE:

We want to make it work.

I think I understand the reason

you might be struggling.

You see, these are scenes...

-Well, sketches.

-...that revolve around acting.

-Michael.

-And that must feel foreign

when you're

a ponytailed vulture

feeding off the corpse

of Lenny Bruce.

(scoffs)

It's okay. He's right.

You're right.

Because I wouldn't want

to make these skits

any worse than

they actually are.

It's a great thing

no one will be watching.

Enjoy your f*cking

little circle jerk!

We already are.

GEORGE:

Oh, your mom's here?

Hmm. Well, he's in character.



(ticking)

LEO:

It's sh*t.

g*dd*mn it, it's just...

(bricks clacking)

(applause)

(cheering)

(bricks clacking and scraping)

Lorne. Lorne.

Lorne.

Oh, Lorne. Great news.

Uh, we figured it out.

Ready?

Ta-da.

We cut the toga sketch.

Oh.

Even without "Alexander,"

we're still 30 over.

Maybe we don't need

four musical performances,

or maybe we could trim

one of the Carlin monologues.

Okay.

What about now?

Are we under now?

-AUDREY: What...

-We can make it work.

Hey, hey. Lorne, Lorne.

Uh, look, I-I know it's

probably a-a bad time and all,

-but, um, uh, Valri and I

have been talking... -Yeah.

...and we can't accept anything

less than four minutes apiece.

So that's four minutes for me,

four minutes for Valri.

Look, we ju... we've just been

working too hard

on our material

to accept anything less,

so it's four minutes

or nothing.

Well, I need two minutes.

You need me to cut

two minutes off my sketch?

I-I could do that, Lorne.

I mean, that's six minutes

only, you know...

No, I need

two minutes of material.

It's two minutes or nothing.

Is this for real? 'Cause...

Okay, I-I k*lled at dress.

Right? I'm the only act

that k*lled at dress.

I can do the show.

Billy, can you make it work

in two minutes?

I can't even set it up in two.

Then I don't know what to say.

I'm sorry it didn't work out.

Can you make it in two?

-Yes.

-Great.

d*ck:

Lorne. Lorne.

-Uh...

-(Lorne sighs)

I was thinking,

why don't we punt?

Come back stronger next week,

debut with Paul Simon.

That's what

you've been thinking?

Listen, no one wants this show

-to succeed more than I do.

-Is that so?

(stammers) I mean, yeah.

I hired you, Lorne.

I take it up the a*s

from this network every day

because I believe in this show.

And I'm telling you, we should

run the dress rehearsal

and claw back a win

next Saturday.

It's in everyone's

best interest, mainly yours.

-Sorry, was that a threat?

-No. What? No.

Uh, Lorne, all I'm trying to do

is give you advice.

25 minutes!

Thanks for the advice,

but we can't, d*ck.

-It's a live show. -No one's

gonna know the difference.

-We just can't.

-Lorne, you need to start

adjusting your concept

of what you can and cannot do.

We can't because

there is no tape.

I didn't record

the dress rehearsal.

So we don't have to argue

about it.

You didn't what?

We just have to make it to air.

Lorne, I'm not gonna be able

to protect you.

-I'm used to that.

-(chuckling) Oh, screw you.

Do you know how much bullshit

never makes it to your ears

because I'm the wall they hit?

Tell that to your Polaroid rep.

She's cute.

I'm sorry you need a sponsor

for a show that can't pull

a single advertiser.

-You know... -You know they're

giving out the ads for free!

NBC is lucky to have something

as relevant as this show.

-Lorne, they don't even

want it. -That's logical, d*ck.

That's why they're

paying us all to be here.

(sighs)

They want you to fail.

-They're betting on it.

-(chuckles) Really?

NBC makes more money playing

reruns of "The Tonight Show."

-(chuckles) I...

-So why don't they?

It's a contract dispute, Lorne.

I mean, th-they're trying

to prove to Johnny Carson

that the reruns are inevitable,

so they built a show

that was guaranteed to fail.

I mean, Lorne,

90 minutes of live television

by a group of 20-year-olds

who have never made anything.

Do you ever stop

and wonder why they said yes?

A counterculture show

starring total unknowns

with zero narrative

and even less structure.

Are you that f*cking arrogant

that you never even

question this?!

Now, look, you want to know

what's gonna happen

at 11:30 tonight, okay?

Your actors will be

on their marks,

band's tuned up,

all ready to go,

Joe will be hollering out

the countdown,

and you'll be

in the control room,

and Dave Tebet will be standing

probably right next to you,

and when those screens

go black,

he will raise his big-a*s,

jeweled-up index finger

and say, "Go to 'Carson,'"

and that will be that.

You blew it.

And listen, I know you all

make fun of me and my clothes

behind my back,

but, Lorne, I'm k*lling myself

for this show.

Also, Polaroid is cool.

(footfalls ascending stairs)

(door opens)

(door closes)

-Oh, sh*t. Lorne.

-It worked.

(breathing heavily)

Nice work, fellas.

A little heavy on the flow,

but very funny.

Uh, sorry about the clothes.

FRANKEN:

And your face.

Art is but a measure

of sacrifice and tears.

Not quite ready for tonight,

but I'll keep it

on a special list.

TOM and FRANKEN:

Special list?

("Nobody Knows the Trouble I've

Seen" by Albert Ayler playing)

Uh, lobby.

This an okay time?

Ideal.

Look...

I know what people say

when they see a man

with his arm up a Muppet.

But this isn't

just kids' stuff.

I believe deep in my heart

that there is room

for high-stakes puppetry

on grown-up TV.

And I get the sense

that some of the writers

on the 17th floor

don't share that dream.

Y-You didn't like the pages?

There were no pages.

(elevator bell dings,

doors open)

That's fair criticism.

-NBC PAGE: Free show.

-(horns honking)

Free show, sir?

Free show.

Plenty of tickets left, guys.

Free show.

The night's still young.

Hey, man. How's it going?

(Lorne breathing heavily)

CRYSTAL:

Thank you. Uh, Long Island.

Massapequa Park.

NBC PAGE:

Hello?



(distant siren wailing)

(laughter inside)

COMEDIAN:

They had trouble

fitting in

when they got to America,

even though

my great-grandfather

actually fought

in the Civil w*r.

He fought for the West.

-(sighs) Jesus Christ.

-LORNE: Vodka, double.

COMEDIAN: This drunk,

he's in front of the bench.

The judge says, "Hey, we

brought you in for drinking."

And the drunk goes,

"Great. What are we having?"

(scattered laughter)

That's not the punch line.

Jesus, f*cking bullshit.

What's happening here?

I get paid seven bucks a joke,

if it gets a laugh, which...

This putz is taking

bulletproof material

-and filling it with lead.

-You wrote his jokes?

Yeah, I wrote things

that vaguely resemble

the things that he's saying.

Why don't you just

perform 'em yourself?

Look at me.

This is how much

I sweat offstage.

COMEDIAN: I get home

from work the other night,

I see my wife in bed

with my best friend.

I say to him, I go,

"I have to, but you?"

ALAN:

Oh, my God.

How many do you have in here?

ALAN:

About 1,100.

They're-they're

single-spaced, so...

Sorry, do you mind

if I go through 'em?

COMEDIAN:

Bring up the next comedian.

ALAN:

Yeah. Go for it.

COMEDIAN:

I'm sure you'll hate him, too.

(scattered applause)

(feedback squealing)

-COMEDIAN: Move.

-(chair drags)

-(Lorne chuckling)

-(comedian sighs)

God, that was f*cking rough.

sh*t crowd.

Yeah, that was it.

Hey, come on.

What's with the quarters?

Well, I changed the punch line

from '46 to '49

for the line about the Buick--

much bigger laugh, by the way--

so that means

I only owe you 3.50.

You want a job?

That would be great.

I want a length of rope

and a sturdy beam.

-COMEDIAN: Wait.

-How much do you need to live?

COMEDIAN:

Whoa, whoa, whoa. Are you...

I make three bucks an hour

at my day job.

-Match it.

-Th-This kid... Tell...

Tell him what you really do.

Tell him.

He's a deli boy, okay?

He's a... he's a schmuck

in a little paper hat

who slices the pastrami

behind the counter.

(laughing)

And he can barely do that.

Tell him what you did

to your finger.

-You're hired. Lorne Michaels.

-COMEDIAN: No, he...

-Alan Zweibel.

-Are you f*cking kidding me?

You'd be better off

buying the pastrami.

-Let's go.

-Wait, what? When do we start?

Um, Jesus Christ.

(comedian stammering)

COMEDIAN: You-you can't...

You better not leave.

You... This is not... This is

not gonna be good for you.

I was gonna take you to Reno.

(water flowing)



(Gilda laughs)

GILDA:

Oh, look at that form.

Beautiful.

(chuckles)

You ever have nostalgia

for a moment

while you're still in it?

I-I-I mean, like, uh...

You're in the moment, but

you're also looking back on it.

Like... right now I-I'm here,

but I'm also

thinking about this moment

20 years from now.

Uh, we're walking

by this ice rink.

Uh, maybe it's Christmas,

and...

our kids are dragging us

by our pinkies

and we got presents loaded

on our shoulders, and...

all we can think about

is this moment

right before we went on TV.

LORNE:

You know, the NBC liability act

forbids you from ice-skating.

-I found John.

-Oh, excellent work, Gilda.

JOHN: Good thing

I didn't sign my contract.

LORNE:

What's the deal, John?

You on the show or not?

The one where I get to dress up

like a giant, grotesque bee?

I don't know.

Let me ask my childhood dreams.

I want to try a triple axel.

-Uh...

-Now we're talking.

(stammering)

How about a single axel?

Nah, I...

I figure I can either

pull off the triple or...

die trying.

Tho-Those are the options?

(Lorne sighs)

(both chuckling)

Okay, John, I... I-I...

I-I support it.

Oh, God.

(exhales)

-He's gonna break something.

-Oh, God.

(grunting)

-sh*t, John!

-Oh, f*ck. John?

-GILDA: John?

-LORNE: Oh, f*ck.

Are you okay?

(groaning)

You all right? I yield.

I accept your surrender.

Do you... do you want me

to help you up?

No, I'm...

I'm just gonna lie here

for a minute.

Okay, sure. Yeah.

We have all the time

in the world.

(Lorne chuckles)

Who is that as*h*le, anyway?

It's Prometheus.

He stole fire from

the cauldron of the gods,

gave it to man so we could have

science and the arts.

Oh.

All right,

I'm gonna head back up.

We have a show

to put on, and...

I'd like to be there

when I get fired.

I'd hope to see

you there, too, John.



(panting)

(elevator bell dings)

-ROSIE: Hey.

-LORNE: Hey.

Heard you needed a quick change

for the last act.

Thank you.

What should I say

when I get up there?

-How should I know?

-You're the writer.

-You're the talker.

-I'm the talker?

Yeah, you talk the peel

off a grape.

That was funny.

Rose, I won't be offended

if you don't want

to use my last name.

It's not your last name,

Lipowitz.

(indistinct chatter)

Whoa.

Check it out.

Full house, right?

LORNE:

What did you tell them?

Well, I kind of had to lie

a little bit,

but the vibes are really good.

-Can we start to let them in?

-Uh, almost.

All right. Five minutes, guys,

ten minutes tops.

Let's keep these vibes going.

-LORNE: Whoa.

-JOE: Here we go! Pardo!

Be prepared

for your intro, please.

Here we go. Keep moving.

-Adequate?

-Adequate.

(d*ck chuckling)

Can you imagine being first up?

-Opening the show and all.

-Millions of people

trying to decide...

FRANKEN: How they want to spend

their Saturday night.

-What's the first thing

they see? -Hmm.

-No logo, no intro.

-Nope.

Just a close-up

of your pretty face.

-Nah.

-Ah, who gives a f*ck, right?

Yeah, it's just

a bunch of animals

-watching their lava lamps.

-You're gonna do great.

-TOM: Yeah.

-f*ck off.

FRANKEN:

We're pulling for you.

TOM:

Break a leg.

You the, uh, writer

Lorne found in a bar?

Uh, that's a slightly romantic

read of the story,

but, uh, yeah, I guess so.

All right.

Well, jump on in. Water's warm.

-Okay.

-(bell ringing)

Okay, quiet, please.

Work stops now.

We're holding

for a sound check.

Who wants to do

the sound check?

Garrett, don't you know a song?

-Hmm?

-(feedback squeals)

Uh... (clears throat)

Uh, yeah. Yeah, yeah, yeah.

(clears throat)

I'm...

Gonna...

Get me a shotgun and k*ll

all the whiteys I see

I'm gonna get me a shotgun

and k*ll

All the whiteys I see

When I k*ll

all the whiteys I see

Then whitey,

he won't bother me

Gonna get me a shotgun and

k*ll all the whiteys I see

I'm gonna get me a shotgun

and k*ll

-All the whiteys I see

-(band joins in, others cheer)

I'm gonna get me a shotgun

and k*ll

All the whiteys I see

When I k*ll

all the whiteys I see

Whitey, he won't bother me

Gonna get me a shotgun

and k*ll all the whiteys I

Get me a shotgun

and k*ll all the whiteys I

Gonna get me a shotgun and

k*ll all the whiteys I see.

(cheering, whooping)

LORNE:

Bravo!

Garrett, that was fantastic.

-GARRETT: Oh, thank you.

-What?

GARRETT:

Thank you.

LORNE: That was terrific.

That was absolutely...

ROSIE:

You have an incredible voice.

-You still not gonna give me

no lines. -It was beautiful.

GARRETT:

Mm-hmm.

Uh, gentlemen, how long

have you been standing there?

-Long enough.

-AUDREY: Lorne,

we need to let the audience in.

No, you don't.

Perhaps you kids aren't quite

ready for prime time.

What-what are you

talking about?

Look around, Lorne.

You haven't locked a script.

Your actors are missing.

Your crew is in open rebellion.

(chuckles)

They'd be laughing at you

in Burbank.

ROSIE:

Burbank?

Excuse me, this is

New York f*cking City.

Who's she?

-She... It's...

-It's... I...

It's complicated.

W-We have a hell of a show.

We have two bands.

We have seven of the brightest

comedy minds alive.

Do you even know

where they are?

Uh, most of them. Yes.

May-Maybe we'll just try again

-next Saturday.

-No. No, no, no.

Don't do that. Come on. No.

Everybody in this room

has been k*lling themselves

-to make something special.

-I know.

-Special? Innovative?

-To make something innovative

-and actually good,

for a change. -For a change?

Don't tell me that you've been

doing this so long

that you can't even recognize

the potential for greatness

when it's right in front

of your face.

Do you even know

what this show is? Tell me.

(Tebet takes a deep breath)

It's an all-nighter

in the city.

It-it-it's catching

Richard Pryor at a drop-in

or finding Paul Simon strumming

in the back of a dive bar.

It's meeting a girl

outside of a bodega

and getting lucky

in a phone booth.

It's...

It's everything you think

is going to happen

when you move to the city.

That's our show.

That's "Saturday Night."

Show me.

Show you what?

Show me "Saturday Night."

I... We go live in less than...

Ten minutes!

No, you don't!

Show me.

("Here I Come to Save the Day"

('Mighty Mouse' Theme) playing)

Mr. Trouble

never hangs around

When he hears

this mighty sound

(lip-synching)

Here I come to save the day

-That means that

-(laughter)

Mighty Mouse is on the way

So though we are in danger,

we never despair

'Cause we know that where

there's danger he is there

He is there on the land,

on the sea

In the air

-We're not worrying at all

-(laughter)

We're just listening

for his call

(lip-synching)

Here I come to save the day

(laughter)

That means that Mighty Mouse

is on the way.

(song ends)

(cheering, laughter)

Andy, you're a genius.

Now save your voice.

Pull up "Weekend Update."

JOE: All right, we're moving

to "Weekend Update."

-Okay.

-JOE: Let's go.

-Hey.

-You take it.

-What do you mean?

-The show needs a face.

Are you sure?

You were born for this.

Trust me.

Should I make up a name

for the news anchor?

Oh, use "Chevy Chase."

No one will believe it.

CREWMAN:

Here we are. Good.

LORNE:

Hey, remember this.

When you look into the lens,

you're making eye contact

with America.

DON: And now, "Weekend Update"

with Chevy Chase.

(grunts)

Hey, doll.

-What are you wearing?

-(light laughter)

Is that why I hear purring?

(laughter)

What do you got for me?

It's my favorite.

Okay, great.

(high-pitched) Good e...

(clears throat)

(normal voice)

Good evening. I'm Chevy Chase.

The Post Office announced today

that it's going to issue

a stamp commemorating

prostitution

in the United States.

It's a ten-cent stamp,

but if you want to lick it,

it's a quarter.

(laughter, applause)

-(whooping)

-JOE: All right, everyone.

Eight minutes till showtime.

(bell ringing)

Open the doors.

Oh, thank God.

Ladies and gentlemen,

Billy Preston.

(band playing

"Nothing from Nothing")

Right this way, folks.

You're in for a real treat.

Yeah! Yeah.

Nothin' from nothin'

leaves nothin'

You gotta have somethin'...

BARBARA:

Lorne, you remember Carl?

LORNE:

Carl? Ooh, Carl!

Have you ever used

one of these before?

Not a once.

You'll pick it up in no time.

You gotta have somethin'

If you wanna be with me

Come on, guys. Grab a brick!

I'm not tryin'

to be your hero

(Preston chuckles)

'Cause that zero

is too cold for me, ha!

I'm not tryin'

to be your highness...

Heard you needed pages.

Aw, thanks, Mike.

Is too low to see

PRESTON:

Come on, now.

Oh, no.

d*ck, uh, question:

What-what is a "golden shower"?

-Oh, uh, it's a yoga ritual...

-d*ck: Mm-hmm.

...in which practitioners

greet the new day

by allowing the golden rays

of sun to...

-Shower.

-Over their skin

-and warm their chakras.

-Mm. It's a California thing.

ROSIE:

Mm.

I've had at least 50

golden showers.

You heard him, Joan.

Sign the damn script.

We're going to air.



Nothin' from nothin'

leaves nothin'

You gotta have somethin'

if you wanna be with me

Don't you remember

I told ya

That I'm a soldier

in the w*r on poverty...

Smith & Wesson K-Frame

Model 19 Combat Magnum.

-Wallie, you son of a b*tch.

-Hey, you asked.

Wallie, my man.

You got something for me?

Yes, you do.

George, I wanted to apologize

for how you were treated...

Whoa, whoa, whoa.

-Are you having a stroke?

-(groans)

-You need more coke?

-(grunts)

Uh, Danny!

(audience clapping rhythmically

to music)

Here, I got you.

Hurry up. Come on, faster.

Watch your fingers.

LEO:

All right.



Oh, boy. Lockjaw.

It's, uh...

it's too much cocaine.

It's seizing up

the old mandibulars.

Let's get some finger love

in there, huh?

-Yep. Just a little bit

of this. -(George grunts)

You'll be fine.

-Okay, great.

-There we go.

(squealing, excited laughter)

PRESTON:

Hey! (laughs)

PRESTON:

Here we go!

Nothin' from nothin'

Nothin' from nothin'

Hey, now

Yeah, yeah, yeah, yeah...

LORNE: Can you get

in that wig in 30 seconds?

-You got it, boss.

-Has Henson got his pages?

-He loves 'em.

-And will that crane get there?

-It'll happen.

-Did you trim the fat on that?

Already on cue cards.

Laraine, I don't think

you can make the change in...

-(bell jingles)

-(wolf whistle)

NEIL:

Whoa.

I stand corrected.

AUDREY:

Is that our show?

-That's our show.

-PRESTON: Oh!

JOE:

Three minutes.

DAN:

Yeah.

(Preston vocalizing)

-Last one. Last one. Get it in.

-Yes!

-Come on! Hey!

-Finally!

-(song ends)

-(cheering and applause)

DON:

Ladies and gentlemen,

Billy Preston.

(cheering continues

over monitors)

(clock ticking)

(cheering and applause

continue)

(laughter)

-Ah.

-Oh, wow.

-Wow. -Photo. Photo.

-Okay.

-Holy...

-I want a photo. Come on.

-Family photo. -No, no, no,

no, no. We're at two minutes.

-There's no time.

-No, come on.

It'll never be the same

after this.

-Come on.

-Oh, f*ck.

I'm not leaving

until I get my photo. Come on.

JOE: I guess everybody

go ahead, then.

Uh, do we have a camera?

-I have a camera.

-JOE: Just quickly.

GILDA:

Great! Yes! Come here!

(Gilda laughing excitedly)



(camera clicks, whirs)

(excited laughter)

JOE:

All right.

60 seconds. Come on, everyone.

-Let's go, please.

-(overlapping chatter)

-After you, after you.

-One minute. Let's go to work.



-Hi.

-(quiet chatter)

LORNE: What are we

using him for again?

ROSIE: I, uh...

I don't really remember.

LORNE:

Sorry.

Thanks.

-Mm, mm, mm. Hey.

-Rocky, wake up!

Hey, hey, name.

Oh, uh, Rosie, we need

your last name for the credits.

-Uh, Shuster.

-Shuster.

(quiet chatter)

30 seconds!

Hey, can we get

a mic check, please?

Uh, uh, one, two,

-uh, uh, three.

-(sighs)

Somebody's got the yips.

-JOE: 20 seconds.

-WILSON: Is Carlin in costume?

Yeah, they settled on

a T-shirt and jacket.

Mr. Carlin, may we get

a mic check?

GEORGE (over speaker):

One, two, f*ck you.

Subtle.

Okay, Carson's still cued

for dead roll?

Are we going live

or going to tape?

Pre-roll on VTR 14.

JOE:

Ten seconds.

-WILSON: Ready, camera two.

-JOE: Seven...

-Pre-roll at six.

-WILSON: Ready on the fade.

JOE:

...six, five, four...

Are we going live

or going to tape?

...three, two...

-Go live.

-AUDREY: Go live.

-Okay. Go live. -Go live!

Go live! -Live, live, live!

WILSON:

Fade up. And we are live.

-(clock ticking)

-(Lorne chuckles uneasily)

WILSON: Ready, camera one.

Take camera one.

BARBARA:

Cue Belushi.

Cue John.

-Where's John?

-AUDREY: Where the hell is he?

WILSON:

Cue John.

(breathing heavily)

(door opens)

(sighs)

(camera clicks)

Good evening.

(foreign accent)

Good evening.

(whispers)

Maybe closer.

(enunciating slowly)

Good evening.

(slowly with foreign accent)

Good evening.

(light laughter)

Good evening.

(laughter)

MICHAEL:

Let us begin.

Repeat after me.

-I would like...

-I would like...

-...to feed your fingertips...

-...to feed your fingertips...

(laughter)

-...to the wolverines.

-...to the wolverines.

(laughter)

MICHAEL:

Next. I am afraid...

JOHN:

I am afraid...

-...we are out...

-...we are out...

-...of badgers.

-...of badgers.

(laughter)

-Would you accept...

-Would you accept...

-...a wolverine...

-...a wolverine...

-...in its place?

-...in its place?

(laughter)

MICHAEL:

Next. "Hey!" Ned exclaimed.

"Hey!" Ned exclaimed.

(laughter)

-"Let's boil..."

-"Let's boil..."

-"...the wolverines."

-"...the wolverines."

Next.

(gasps sharply)

(Rosie chuckles)

(gasps sharply)

(laughter)

(cheering, applause)

Live from New York,

it's "Saturday Night"!

(cheering)

(Howard Shore's "'Saturday

Night' Opening Theme" playing)

(theme ends)

MAN: Aaah! All right,

we gonna do it again.

Now we got it, now we got it.

Go back, go back, go back.